@@ -10,22 +10,28 @@ import tornado.web
 import tornado.ioloop
 import tornado.websocket
 import tornado.httpserver
-from tornado.httputil import HTTPHeaders
-
 import os, sys
 
+
 sys.path.append(os.getcwd())
-from app.app_core import AppCore
+use_oop = True
+try:
+    # 如果 ./app/ 目录下存在 app_main.py 文件，则模型主程序使用非面向对象模式编程，忽略同目录下的 app_core.py 文件（如果存在）
+    from app import app_main
+    use_oop = False
+except:
+    # 如果 ./core/ 目录下存在 model_main.py 文件，则模型主程序使用面向对象模式编程
+    from app.app_core import AppCore
+    use_oop = True
 
 
 class GlobalData:
     def __init__(self):
         self.app_core = None
-        self.is_gateway = False
 
     def init_global_data(self):
         try:
-            self.app_core = AppCore()
+            self.app_core = AppCore() if use_oop else app_main
             return True
         except Exception as e:
             logging.error(str(e))
@@ -45,18 +51,27 @@ class DataApi(tornado.web.RequestHandler):
             logging.error(str(e))
             result = {
                 'status': 'err',
-                'value': 'HTTP请求体错误！' + str(e)
+                'value': 'HTTP请求体错误：' + str(e)
             }
             self.write(result)
             return
 
+        input['request_info'] = {}
+        input['request_info']['http_request'] = self.request
+        authorization = self.request.headers.get('Authorization')
+        if authorization and authorization.lower().startswith('bearer'):
+            input['request_info']['jwt'] = authorization[7:]  # 去除前缀“Bearer ”
+        if authorization and authorization.lower().startswith('basic'):
+            input['request_info']['auth_basic'] = authorization[6:]  # 去除前缀“Basic ”
+
         output = {
             'result': {},
             'finish': False
         }
+
         thread = threading.Thread(
             target=data_service,
-            args=(input, output, self.request)
+            args=(input, output)
         )
         thread.setDaemon(True)
         thread.start()
@@ -65,11 +80,6 @@ class DataApi(tornado.web.RequestHandler):
             await asyncio.sleep(0.01)
         result = output['result']
 
-        # 特例，针对gateway上的 login 和 logout
-        if g.is_gateway and result['status'] == 'ok':
-            self.set_cookie('access_token', result['value']['access_token'])
-            self.set_cookie('refresh_token', result['value']['refresh_token'])
-
         if self.request.headers.get('Origin'):
             self.set_header('Access-Control-Allow-Credentials', 'true')
             self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
@@ -87,7 +97,7 @@ class DataApi(tornado.web.RequestHandler):
         self.set_header('Access-Control-Allow-Methods', 'GET, POST, OPTIONS')
 
 
-def data_service(input, output, http_request):
+def data_service(input, output):
     if not isinstance(input, dict):
         result = {
             'value': 'HTTP请求体不是JSON格式！',
@@ -98,10 +108,8 @@ def data_service(input, output, http_request):
         return
 
     action = input.get('action')
-    kwargs = input.get('args')
-    if kwargs is None:
-        kwargs = {}
-    kwargs['http_request'] = http_request
+    args = input.get('args')
+    threading.current_thread().request_info = input.get('request_info')
 
     if action is None:
         result = {
@@ -112,7 +120,7 @@ def data_service(input, output, http_request):
         output['finish'] = True
         return
 
-    public_actions = getattr(AppCore, 'public_actions', None)
+    public_actions = getattr(g.app_core, 'public_actions', None)
     if public_actions is not None:
         if action not in public_actions:
             result = {
@@ -123,8 +131,7 @@ def data_service(input, output, http_request):
             output['finish'] = True
             return
 
-    model = g.app_core
-    action_obj = getattr(model, action, None)
+    action_obj = getattr(g.app_core, action, None)
     if action_obj is None:
         result = {
             'value': 'Action: {} 未定义！'.format(action),
@@ -136,7 +143,7 @@ def data_service(input, output, http_request):
 
     result = {}
     try:
-        result['value'] = action_obj(**kwargs) if kwargs else action_obj()  # kwargs为None或{}时，不带参数调用
+        result['value'] = action_obj(**args) if args else action_obj()  # kwargs为None或{}时，不带参数调用
         result['status'] = 'ok'
     except Exception as e:
         logging.error(str(e))
@@ -154,23 +161,30 @@ class StreamApi(tornado.web.RequestHandler):
         if '/' in path:
             i = path.find('/')
             action = path[:i]
-            path_arg = path[i + 1:]
+            path_args = path[i + 1:]
         else:
             action = path
-            path_arg = None
+            path_args = None
 
         input = {
             'action': action,
-            'args': {
-                'stream': self.request.body,
-                'path_arg': path_arg,
-                'http_request': self.request,
-            }
+            'bytestream': self.request.body,
+            'request_info': {},
         }
+        input['request_info']['http_request'] = self.request
+        if path_args:
+            input['request_info']['path_args'] = path_args
+        authorization = self.request.headers.get('Authorization')
+        if authorization and authorization.lower().startswith('bearer'):
+            input['request_info']['jwt'] = authorization[7:]  # 去除前缀“Bearer ”
+        if authorization and authorization.lower().startswith('basic'):
+            input['request_info']['auth_basic'] = authorization[6:]  # 去除前缀“Basic ”
+
         output = {
             'result': {},
             'finish': False
         }
+
         thread = threading.Thread(
             target=stream_service,
             args=(input, output)
@@ -201,9 +215,10 @@ class StreamApi(tornado.web.RequestHandler):
 
 def stream_service(input, output):
     action = input.get('action')
-    args = input.get('args')
+    bytestream = input.get('bytestream')
+    threading.current_thread().request_info = input.get('request_info')
 
-    public_actions = getattr(AppCore, 'public_actions', None)
+    public_actions = getattr(g.app_core, 'public_actions', None)
     if public_actions is not None:
         if action not in public_actions:
             result = {
@@ -214,8 +229,7 @@ def stream_service(input, output):
             output['finish'] = True
             return
 
-    model = g.app_core
-    action_obj = getattr(model, action, None)
+    action_obj = getattr(g.app_core, action, None)
     if action_obj is None:
         result = {
             'value': 'Action: {} 未定义！'.format(action),
@@ -227,7 +241,7 @@ def stream_service(input, output):
 
     result = {}
     try:
-        result['value'] = action_obj(**args)
+        result['value'] = action_obj(bytestream)
         result['status'] = 'ok'
     except Exception as e:
         logging.error(str(e))
@@ -245,31 +259,39 @@ class FileApi(tornado.web.RequestHandler):
         if '/' in path:
             i = path.find('/')
             action = path[:i]
-            path_arg = path[i + 1:]
+            path_args = path[i + 1:]
         else:
             action = path
-            path_arg = None
+            path_args = None
 
         try:
             file_obj = self.request.files.get(action)[0]
             file_body = file_obj.body
+            filename = file_obj.filename
         except Exception as e:
             logging.error(str(e))
             result = {
                 'status': 'err',
-                'value': 'HTTP文件上传请求体错误！' + str(e)
+                'value': 'HTTP文件上传请求体错误：' + str(e)
             }
             self.write(result)
             return
 
         input = {
             'action': action,
-            'args': {
-                'stream': file_body,
-                'path_arg': path_arg,
-                'http_request': self.request,
-            }
+            'bytestream': file_body,
+            'request_info': {},
         }
+        input['request_info']['http_request'] = self.request
+        input['request_info']['filename'] = filename
+        if path_args:
+            input['request_info']['path_args'] = path_args
+        authorization = self.request.headers.get('Authorization')
+        if authorization and authorization.lower().startswith('bearer'):
+            input['request_info']['jwt'] = authorization[7:]  # 去除前缀“Bearer ”
+        if authorization and authorization.lower().startswith('basic'):
+            input['request_info']['auth_basic'] = authorization[6:]  # 去除前缀“Basic ”
+
         output = {
             'result': {},
             'finish': False
@@ -302,263 +324,28 @@ class FileApi(tornado.web.RequestHandler):
         self.set_header('Access-Control-Allow-Methods', 'GET, POST, OPTIONS')
 
 
-class GatewayApi(tornado.web.RequestHandler):
-
-    async def get(self, *args, **kwargs):
-        output = {
-            'result': {},
-            'finish': False
-        }
-        thread = threading.Thread(
-            target=gateway_service,
-            args=(self.request, output)
-        )
-        thread.setDaemon(True)
-        thread.start()
-
-        while not output['finish']:
-            await asyncio.sleep(0.01)
-        result = output['result']
-
-        if result['status'] == 'ok':
-            new_access_token = result['value'].get('new_access_token')  # 用 get 而不是 [] 来取值，因为可能不存在
-            new_refresh_token = result['value'].get('new_refresh_token')
-            response = result['value']['response']
-
-            if new_access_token is not None and new_refresh_token is not None:
-                self.set_cookie('access_token', new_access_token)
-                self.set_cookie('refresh_token', new_refresh_token)
-
-            self.set_status(response.status_code)
-            self._headers = HTTPHeaders(response.headers)  # 注意：需要强制类型转换
-
-            if self._headers.get('Content-Type') == 'gzip':
-                try:
-                    self._headers.pop('Content-Type')
-                    self._headers.pop('Content-Length')
-                except:
-                    pass
-
-            if self._headers.get('Transfer-Encoding'):
-                self._headers.pop('Transfer-Encoding')
-
-            if self._headers.get('Content-Length') is not None:
-                self.set_header('Content-Length', len(response.content))
-
-            if self.request.headers.get('Origin'):
-                self.set_header('Access-Control-Allow-Credentials', 'true')
-                self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
-
-            if self._status_code in (204, 304) or 100 <= self._status_code < 200:
-                # 这些状态下response中不能有body，所以不应该write
-                return
-
-            if response.status_code != 500:
-                self.write(response.content)
-            else:
-                if self._headers.get('Content-Length') is not None:
-                    self._headers.pop('Content-Length')
-                self.write('服务未启动！')
-        else:
-            self.set_status(500)
-            # self.write(result['value'])
-            self.write('服务未启动！')
-
-    async def post(self, *args, **kwargs):
-        output = {
-            'result': {},
-            'finish': False
-        }
-        thread = threading.Thread(
-            target=gateway_service,
-            args=(self.request, output)
-        )
-        thread.setDaemon(True)
-        thread.start()
-
-        while not output['finish']:
-            await asyncio.sleep(0.01)
-        result = output['result']
-
-        if result['status'] == 'ok':
-            new_access_token = result['value'].get('new_access_token')  # 用 get 而不是 [] 来取值，因为可能不存在
-            new_refresh_token = result['value'].get('new_refresh_token')
-            response = result['value']['response']
-
-            if new_access_token is not None and new_refresh_token is not None:
-                self.set_cookie('access_token', new_access_token)
-                self.set_cookie('refresh_token', new_refresh_token)
-
-            self.set_status(response.status_code)
-            self._headers = HTTPHeaders(response.headers)  # 注意：需要强制类型转换
-
-            if self._headers.get('Content-Type') == 'gzip':
-                try:
-                    self._headers.pop('Content-Type')
-                    self._headers.pop('Content-Length')
-                except:
-                    pass
-
-            if self._headers.get('Transfer-Encoding'):
-                self._headers.pop('Transfer-Encoding')
-
-            if self._headers.get('Content-Length') is not None:
-                self.set_header('Content-Length', len(response.content))
-
-            if self.request.headers.get('Origin'):
-                self.set_header('Access-Control-Allow-Credentials', 'true')
-                self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
-
-            if self._status_code in (204, 304) or 100 <= self._status_code < 200:
-                # 这些状态下response中不能有body，所以不应该write
-                return
-
-            self.write(response.content)
-        else:
-            self.set_status(500)
-            self.write(result['value'])
-
-    async def put(self, *args, **kwargs):
-        output = {
-            'result': {},
-            'finish': False
-        }
-        thread = threading.Thread(
-            target=gateway_service,
-            args=(self.request, output)
-        )
-        thread.setDaemon(True)
-        thread.start()
-
-        while not output['finish']:
-            await asyncio.sleep(0.01)
-        result = output['result']
-
-        if result['status'] == 'ok':
-            new_access_token = result['value'].get('new_access_token')  # 用 get 而不是 [] 来取值，因为可能不存在
-            new_refresh_token = result['value'].get('new_refresh_token')
-            response = result['value']['response']
-
-            if new_access_token is not None and new_refresh_token is not None:
-                self.set_cookie('access_token', new_access_token)
-                self.set_cookie('refresh_token', new_refresh_token)
-
-            self.set_status(response.status_code)
-            self._headers = HTTPHeaders(response.headers)  # 注意：需要强制类型转换
-
-            if self._headers.get('Content-Type') == 'gzip':
-                try:
-                    self._headers.pop('Content-Type')
-                    self._headers.pop('Content-Length')
-                except:
-                    pass
-
-            if self._headers.get('Transfer-Encoding'):
-                self._headers.pop('Transfer-Encoding')
-
-            if self._headers.get('Content-Length') is not None:
-                self.set_header('Content-Length', len(response.content))
-
-            if self.request.headers.get('Origin'):
-                self.set_header('Access-Control-Allow-Credentials', 'true')
-                self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
-
-            if self._status_code in (204, 304) or 100 <= self._status_code < 200:
-                # 这些状态下response中不能有body，所以不应该write
-                return
-
-            self.write(response.content)
-        else:
-            self.set_status(500)
-            self.write(result['value'])
-
-    async def delete(self, *args, **kwargs):
-        output = {
-            'result': {},
-            'finish': False
-        }
-        thread = threading.Thread(
-            target=gateway_service,
-            args=(self.request, output)
-        )
-        thread.setDaemon(True)
-        thread.start()
-
-        while not output['finish']:
-            await asyncio.sleep(0.01)
-        result = output['result']
-
-        if result['status'] == 'ok':
-            new_access_token = result['value'].get('new_access_token')  # 用 get 而不是 [] 来取值，因为可能不存在
-            new_refresh_token = result['value'].get('new_refresh_token')
-            response = result['value']['response']
-
-            if new_access_token is not None and new_refresh_token is not None:
-                self.set_cookie('access_token', new_access_token)
-                self.set_cookie('refresh_token', new_refresh_token)
-
-            self.set_status(response.status_code)
-            self._headers = HTTPHeaders(response.headers)  # 注意：需要强制类型转换
-
-            if self._headers.get('Content-Type') == 'gzip':
-                try:
-                    self._headers.pop('Content-Type')
-                    self._headers.pop('Content-Length')
-                except:
-                    pass
-
-            if self._headers.get('Transfer-Encoding'):
-                self._headers.pop('Transfer-Encoding')
-
-            if self._headers.get('Content-Length') is not None:
-                self.set_header('Content-Length', len(response.content))
-
-            if self.request.headers.get('Origin'):
-                self.set_header('Access-Control-Allow-Credentials', 'true')
-                self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
-
-            if self._status_code in (204, 304) or 100 <= self._status_code < 200:
-                # 这些状态下response中不能有body，所以不应该write
-                return
-
-            self.write(response.content)
-        else:
-            self.set_status(500)
-            self.write(result['value'])
-
-    async def options(self, *args, **kwargs):
-        # 允许跨域
-        self.set_status(204)
-        self.set_header('Access-Control-Allow-Credentials', 'true')
-        self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
-        self.set_header("Access-Control-Allow-Headers", "content-type")
-        self.set_header('Access-Control-Allow-Methods', 'GET, POST, PUT, DELETE, OPTIONS')
-
-
-def gateway_service(prev_request, output):
-    result = {}
-    try:
-        result['value'] = g.app_core.forward_request(prev_request)
-        result['status'] = 'ok'
-    except Exception as e:
-        logging.error(str(e))
-        result['value'] = str(e)
-        result['status'] = 'err'
-
-    output['result'] = result
-    output['finish'] = True
-
-
 class SpecialApi(tornado.web.RequestHandler):
 
     async def get(self, *args, **kwargs):
+
+        input = {
+            'request_info': {},
+        }
+        input['request_info']['http_request'] = self.request
+        authorization = self.request.headers.get('Authorization')
+        if authorization and authorization.lower().startswith('bearer'):
+            input['request_info']['jwt'] = authorization[7:]  # 去除前缀“Bearer ”
+        if authorization and authorization.lower().startswith('basic'):
+            input['request_info']['auth_basic'] = authorization[6:]  # 去除前缀“Basic ”
+
         output = {
             'result': {},
             'finish': False
         }
+
         thread = threading.Thread(
             target=special_service,
-            args=(self.request, output)
+            args=(input, output)
         )
         thread.setDaemon(True)
         thread.start()
@@ -577,13 +364,25 @@ class SpecialApi(tornado.web.RequestHandler):
             self.write(result['value'])
 
     async def post(self, *args, **kwargs):
+
+        input = {
+            'request_info': {},
+        }
+        input['request_info']['http_request'] = self.request
+        authorization = self.request.headers.get('Authorization')
+        if authorization and authorization.lower().startswith('bearer'):
+            input['request_info']['jwt'] = authorization[7:]  # 去除前缀“Bearer ”
+        if authorization and authorization.lower().startswith('basic'):
+            input['request_info']['auth_basic'] = authorization[6:]  # 去除前缀“Basic ”
+
         output = {
             'result': {},
             'finish': False
         }
+
         thread = threading.Thread(
             target=special_service,
-            args=(self.request, output)
+            args=(input, output)
         )
         thread.setDaemon(True)
         thread.start()
@@ -602,13 +401,25 @@ class SpecialApi(tornado.web.RequestHandler):
             self.write(result['value'])
 
     async def put(self, *args, **kwargs):
+
+        input = {
+            'request_info': {},
+        }
+        input['request_info']['http_request'] = self.request
+        authorization = self.request.headers.get('Authorization')
+        if authorization and authorization.lower().startswith('bearer'):
+            input['request_info']['jwt'] = authorization[7:]  # 去除前缀“Bearer ”
+        if authorization and authorization.lower().startswith('basic'):
+            input['request_info']['auth_basic'] = authorization[6:]  # 去除前缀“Basic ”
+
         output = {
             'result': {},
             'finish': False
         }
+
         thread = threading.Thread(
             target=special_service,
-            args=(self.request, output)
+            args=(input, output)
         )
         thread.setDaemon(True)
         thread.start()
@@ -627,13 +438,25 @@ class SpecialApi(tornado.web.RequestHandler):
             self.write(result['value'])
 
     async def delete(self, *args, **kwargs):
+
+        input = {
+            'request_info': {},
+        }
+        input['request_info']['http_request'] = self.request
+        authorization = self.request.headers.get('Authorization')
+        if authorization and authorization.lower().startswith('bearer'):
+            input['request_info']['jwt'] = authorization[7:]  # 去除前缀“Bearer ”
+        if authorization and authorization.lower().startswith('basic'):
+            input['request_info']['auth_basic'] = authorization[6:]  # 去除前缀“Basic ”
+
         output = {
             'result': {},
             'finish': False
         }
+
         thread = threading.Thread(
             target=special_service,
-            args=(self.request, output)
+            args=(input, output)
         )
         thread.setDaemon(True)
         thread.start()
@@ -660,10 +483,11 @@ class SpecialApi(tornado.web.RequestHandler):
         self.set_header('Access-Control-Allow-Methods', 'GET, POST, PUT, DELETE, OPTIONS')
 
 
-def special_service(request, output):
+def special_service(input, output):
+    threading.current_thread().request_info = input.get('request_info')
     result = {}
     try:
-        result['value'] = g.app_core.special_api(request)
+        result['value'] = g.app_core.special_api()
         result['status'] = 'ok'
     except Exception as e:
         logging.error(str(e))
@@ -674,62 +498,7 @@ def special_service(request, output):
     output['finish'] = True
 
 
-class ThirdPartyOauthApi(tornado.web.RequestHandler):
-
-    async def get(self, *args, **kwargs):
-        output = {
-            'result': {},
-            'finish': False
-        }
-        thread = threading.Thread(
-            target=third_party_oauth_service,
-            args=(self.request, output)
-        )
-        thread.setDaemon(True)
-        thread.start()
-
-        while not output['finish']:
-            await asyncio.sleep(0.01)
-        result = output['result']
-
-        if result['status'] == 'ok':
-            if self.request.headers.get('Origin'):
-                self.set_header('Access-Control-Allow-Credentials', 'true')
-                self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
-
-            self.set_cookie('access_token', result['value']['access_token'])
-            self.set_cookie('refresh_token', result['value']['refresh_token'])
-            self.set_header('Location', '/')
-            self.set_status(302)
-        else:
-            self.set_status(400)
-            self.write(result['value'])
-
-    async def options(self, *args, **kwargs):
-        # 允许跨域
-        self.set_status(204)
-        self.set_header('Access-Control-Allow-Credentials', 'true')
-        self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
-        self.set_header("Access-Control-Allow-Headers", "content-type")
-        self.set_header('Access-Control-Allow-Methods', 'GET, POST, PUT, DELETE, OPTIONS')
-
-
-def third_party_oauth_service(request, output):
-    result = {}
-    try:
-        result['value'] = g.app_core.third_party_oauth(request)
-        result['status'] = 'ok'
-    except Exception as e:
-        logging.error(str(e))
-        result['value'] = str(e)
-        result['status'] = 'err'
-
-    output['result'] = result
-    output['finish'] = True
-
-
-class WebSocketHub(tornado.websocket.WebSocketHandler):
-    topic_connections = {}
+class WebSocketServer(tornado.websocket.WebSocketHandler):
 
     def open(self):
         pass
@@ -742,51 +511,31 @@ class WebSocketHub(tornado.websocket.WebSocketHandler):
             logging.error('WebSocket消息必须采用JSON格式！')
             return
 
-        if msg.get('type') == 'subscribe':
-            if getattr(self, 'topic', None) is not None:
-                logging.error('WebSocket已订阅过主题，不能更改！')
-                return
-
-            self.topic = msg.get('content')
-            if self.topic is not None:
-                connections = self.topic_connections.get(self.topic)
-                if connections is None:
-                    self.topic_connections[self.topic] = [self]
-                else:
-                    connections.append(self)
-                logging.critical('New WebSocket connection opened for topic: {}'.format(self.topic))
-                self.write_message({
-                    'type': 'welcome',
-                    'content': 'New WebSocket connection opened for topic: {}'.format(self.topic),
-                })
-            else:
-                logging.error('Invalid WebSocket topic : None')
-                self.close()
-        else:
-            topic = msg.get('topic')
-            if topic is None:
-                return
-            # 转发消息
-            connections = self.topic_connections.get(topic)
-            if isinstance(connections, list):
-                for conn in connections:
-                    conn.write_message(msg)
+        thread = threading.Thread(
+            target=websocket_message_runner,
+            args=(asyncio.get_event_loop(), self, msg)
+        )
+        thread.setDaemon(True)
+        thread.start()
 
     def on_close(self):
-        connections = self.topic_connections.get(self.topic)
-        if isinstance(connections, list):
-            connections.pop(connections.index(self))
-            if len(connections) == 0:
-                self.topic_connections.pop(self.topic)
-            logging.critical('WebSocket connection subscribed to topic: {} closed'.format(self.topic))
+        logging.critical('websocket closed')
 
     def check_origin(self, origin):
         return True
 
 
+def websocket_message_runner(event_loop, websocket, msg):
+    asyncio.set_event_loop(event_loop)
+    try:
+        g.app_core.process_websocket_message(websocket, msg)
+    except Exception as e:
+        logging.error(str(e))
+
+
 class HealthChecker(tornado.web.RequestHandler):
     def get(self, *args, **kwargs):
-        self.write('{"description": "Micro-service Discovery Client", "status": "UP"}')
+        self.write('{"description": "ServiceBoot", "status": "UP"}')
 
 
 def get_local_ip():
@@ -813,25 +562,25 @@ def start():
         return
 
     try:
-        ename = yml['service']['ename']
+        ename = yml['serviceboot']['ename']
     except:
         logging.error('未指定服务英文名！请在application.yml文件中编辑修改...')
         return
 
     try:
-        cname = yml['service']['cname']
+        cname = yml['serviceboot']['cname']
     except:
         cname = ename.upper()
 
     if app_profile == 'dev':
         try:
-            port = yml['service']['port']['dev']
+            port = yml['serviceboot']['port']['dev']
         except:
             logging.error('未指定服务端口号！缺省使用80端口。')
             port = 80
     else:
         try:
-            port = yml['service']['port']['prod']
+            port = yml['serviceboot']['port']['prod']
         except:
             logging.error('未指定服务端口号！缺省使用80端口。')
             port = 80
@@ -840,34 +589,19 @@ def start():
         logging.error('微服务： {}/{} 初始化失败！'.format(cname, ename))
         return
 
-    is_gateway = False
-    try:
-        is_gateway = yml['gateway']['is_gateway']
-    except:
-        pass
-
-    if is_gateway:
-        g.is_gateway = True
-        handlers = [
-            (r'/management/health', HealthChecker),
-            (r'/api/data', DataApi),
-            (r'/oauth/(.*)', ThirdPartyOauthApi),
-            (r'/websocket', WebSocketHub),
-            (r'/(.*)', GatewayApi),
-        ]
-    else:
-        handlers = [
-            (r'/management/health', HealthChecker),
-            (r'/special/(.*)', SpecialApi),
-            (r'/api/data', DataApi),
-            (r'/api/stream/(.*)', StreamApi),
-            (r'/api/file/(.*)', FileApi),
-            (r'/(.*)', tornado.web.StaticFileHandler, {'path': 'webapp/www', 'default_filename': 'index.html'}),
-        ]
+    handlers = [
+        (r'/management/health', HealthChecker),
+        (r'/special/(.*)', SpecialApi),
+        (r'/api/data', DataApi),
+        (r'/api/stream/(.*)', StreamApi),
+        (r'/api/file/(.*)', FileApi),
+        (r'/websocket', WebSocketServer),
+        (r'/(.*)', tornado.web.StaticFileHandler, {'path': 'webapp/www', 'default_filename': 'index.html'}),
+    ]
 
     debug = 'dev' == app_profile  # 开发模式缺省启动debug
     try:
-        process_number = yml['process_number']  # 如果yml配置文件中指定了进程数，则强制使用
+        process_number = yml['serviceboot']['process_num']  # 如果yml配置文件中指定了进程数，则强制使用
         if debug:
             debug = 1 == process_number  # 开发模式模式下，如果yml配置文件中指定了进程数不为1，则强制关闭debug
     except:
@@ -884,9 +618,16 @@ def start():
     http_server.bind(port)
     http_server.start(num_processes=process_number)
 
+    try:
+        has_web = yml['serviceboot']['has_web']  # 如果yml配置文件中指定了进程数，则强制使用
+    except:
+        has_web = False
+
     logging.critical('##################################################')
-    logging.critical('    微服务： {}/{} started ...'.format(cname, ename))
+    logging.critical('    ServiceBoot微服务： {}/{} started ...'.format(cname, ename))
     logging.critical('    Listening at: {}:{}'.format(get_local_ip(), port))
+    if has_web:
+        logging.critical('    Web access: http://{}:{}/'.format(get_local_ip(), port))
     logging.critical('    App profile: {}'.format(app_profile))
     logging.critical('##################################################')
     tornado.ioloop.IOLoop.current().start()
